v2.3 - Nautobot Design Builder Documentation

Skip to content

# v2.3 Release Notes

This document describes all new features and changes in the release. The format is based on Keep a Changelog and this project adheres to Semantic Versioning.

## Release Overview

- Changed minimum Nautobot version to 2.4.20.
- Dropped support for Python versions 3.8 and 3.9.

## v2.3.0 (2025-12-09)

### Added

- #219 - Added a public testing framework by updating and moving DesignTestCase, BuilderChecks.
- #219 - Added to public testing framework by creating a small convenience method VerifyDesignTestCase.

### Fixed

- #204 - Fixed a problem when creating rack reservations.
- #253 - Fixed multiple search and filtering bugs.

### Documentation

- #219 - Documented a public testing and checks framework.

### Housekeeping

- #228 - Added Virtualization examples in tests.
- #244 - Implemented Component UI for detail views.
- #566 - Pinned Django debug toolbar to <6.0.0.
- Rebaked from the cookie `nautobot-app-v2.4.2`.
- Rebaked from the cookie `nautobot-app-v2.5.0`.
- Rebaked from the cookie `nautobot-app-v2.5.1`.
- Rebaked from the cookie `nautobot-app-v2.6.0`.
- Rebaked from the cookie `nautobot-app-v2.7.0`.
- Rebaked from the cookie `nautobot-app-v2.7.1`.
- Rebaked from the cookie `nautobot-app-v2.7.2`.